@@ -11,10 +11,10 @@ import typing_extensions
 from typeguard import check_type
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@awscdk/asset-node-proxy-agent-v5",
-    "2.0.1",
+    "@aws-cdk/asset-node-proxy-agent-v5",
+    "2.0.2",
     __name__[0:-6],
-    "asset-node-proxy-agent-v5@2.0.1.jsii.tgz",
+    "asset-node-proxy-agent-v5@2.0.2.jsii.tgz",
 )
 
 __all__ = [
